WebViewLoadError class

Constructors

WebViewLoadError({required String description, int? code, String? url, bool? isForMainFrame})
const

Properties

code int?
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
isForMainFrame bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited