CreateConfiguration class

Constructors

CreateConfiguration({int windowWidth = 1280, int windowHeight = 720, String title = "", int titleBarHeight = 0, int titleBarTopPadding = 0, String userDataFolderWindows = 'webview_window_WebView2'})
const
CreateConfiguration.platform()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
the title of window
final
titleBarHeight int
Height of the optional Flutter-powered title bar.
final
titleBarTopPadding int
final
userDataFolderWindows String
final
windowHeight int
final
windowWidth int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited