Webview class abstract

Implementers

Constructors

Webview()

Properties

hashCode int
The hash code for this object.
no setterinherited
isNavigating ValueListenable<bool>
true if the webview is currently loading a page.
no setter
onClose Future<void>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addOnUrlRequestCallback(OnUrlRequestCallback callback) → void
addOnWebMessageReceivedCallback(OnWebMessageReceivedCallback callback) → void
addScriptToExecuteOnDocumentCreated(String javaScript) Future<void>
back() Future<void>
Navigate to the previous page in the history.
close() Future<void>
Close the web view window.
evaluateJavaScript(String javaScript) Future<String?>
evaluate JavaScript in the web view.
forward() Future<void>
Navigate to the next page in the history.
launch(String url) Future<void>
Navigates to the given URL.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDevToolsWindow() Future<void>
Opens the Browser DevTools in a separate window on Windows.
postWebMessageAsJson(String webMessage) Future<void>
Posts a web message as JSON on Windows.
postWebMessageAsString(String webMessage) Future<void>
Posts a web message as a string on Windows.
registerJavaScriptMessageHandler(String name, JavaScriptMessageHandler handler) Future<void>
Install a message handler that you can call from your Javascript code.
reload() Future<void>
Reload the current page.
removeOnUrlRequestCallback(OnUrlRequestCallback callback) → void
removeOnWebMessageReceivedCallback(OnWebMessageReceivedCallback callback) → void
setApplicationNameForUserAgent(String applicationName) Future<void>
Append a string to the webview's user-agent.
setBrightness(Brightness? brightness) Future<void>
change webview theme.
setOnHistoryChangedCallback(OnHistoryChangedCallback? callback) → void
Register a callback that will be invoked when the webview history changes.
setOnNavigationErrorCallback(OnNavigationErrorCallback? callback) → void
Registers the callback used for main-frame navigation failures.
setPromptHandler(PromptHandler? handler) → void
available: macOS
stop() Future<void>
Stop all navigations and pending resource fetches.
toString() String
A string representation of this object.
inherited
unregisterJavaScriptMessageHandler(String name) Future<void>
available: macOS

Operators

operator ==(Object other) bool
The equality operator.
inherited